@@ -1,6 +1,6 @@
 import xcffib
 import struct
-import six
+import io
 MAJOR_VERSION = 1
 MINOR_VERSION = 4
 key = xcffib.ExtensionKey("DRI2")
@@ -35,7 +35,7 @@ class DRI2Buffer(xcffib.Struct):
         self.attachment, self.name, self.pitch, self.cpp, self.flags = unpacker.unpack("IIIII")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IIIII", self.attachment, self.name, self.pitch, self.cpp, self.flags))
         return buf.getvalue()
     fixed_size = 20
@@ -57,7 +57,7 @@ class AttachFormat(xcffib.Struct):
         self.attachment, self.format = unpacker.unpack("II")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=II", self.attachment, self.format))
         return buf.getvalue()
     fixed_size = 8
@@ -193,7 +193,7 @@ class BufferSwapCompleteEvent(xcffib.Event):
         self.event_type, self.drawable, self.ust_hi, self.ust_lo, self.msc_hi, self.msc_lo, self.sbc = unpacker.unpack("xx2xH2xIIIIII")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
         buf.write(struct.pack("=x2xH2xIIIIII", self.event_type, self.drawable, self.ust_hi, self.ust_lo, self.msc_hi, self.msc_lo, self.sbc))
         buf_len = len(buf.getvalue())
@@ -221,7 +221,7 @@ class InvalidateBuffersEvent(xcffib.Event):
         self.drawable, = unpacker.unpack("xx2xI")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 1))
         buf.write(struct.pack("=x2xI", self.drawable))
         buf_len = len(buf.getvalue())
@@ -236,61 +236,61 @@ class InvalidateBuffersEvent(xcffib.Event):
 _events[1] = InvalidateBuffersEvent
 class dri2Extension(xcffib.Extension):
     def QueryVersion(self, major_version, minor_version, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", major_version, minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
     def Connect(self, window, driver_type, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", window, driver_type))
         return self.send_request(1, buf, ConnectCookie, is_checked=is_checked)
     def Authenticate(self, window, magic, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", window, magic))
         return self.send_request(2, buf, AuthenticateCookie, is_checked=is_checked)
     def CreateDrawable(self, drawable, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", drawable))
         return self.send_request(3, buf, is_checked=is_checked)
     def DestroyDrawable(self, drawable, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", drawable))
         return self.send_request(4, buf, is_checked=is_checked)
     def GetBuffers(self, drawable, count, attachments_len, attachments, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", drawable, count))
         buf.write(xcffib.pack_list(attachments, "I"))
         return self.send_request(5, buf, GetBuffersCookie, is_checked=is_checked)
     def CopyRegion(self, drawable, region, dest, src, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIII", drawable, region, dest, src))
         return self.send_request(6, buf, CopyRegionCookie, is_checked=is_checked)
     def GetBuffersWithFormat(self, drawable, count, attachments_len, attachments, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", drawable, count))
         buf.write(xcffib.pack_list(attachments, AttachFormat))
         return self.send_request(7, buf, GetBuffersWithFormatCookie, is_checked=is_checked)
     def SwapBuffers(self, drawable, target_msc_hi, target_msc_lo, divisor_hi, divisor_lo, remainder_hi, remainder_lo, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIIIIII", drawable, target_msc_hi, target_msc_lo, divisor_hi, divisor_lo, remainder_hi, remainder_lo))
         return self.send_request(8, buf, SwapBuffersCookie, is_checked=is_checked)
     def GetMSC(self, drawable, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", drawable))
         return self.send_request(9, buf, GetMSCCookie, is_checked=is_checked)
     def WaitMSC(self, drawable, target_msc_hi, target_msc_lo, divisor_hi, divisor_lo, remainder_hi, remainder_lo, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIIIIII", drawable, target_msc_hi, target_msc_lo, divisor_hi, divisor_lo, remainder_hi, remainder_lo))
         return self.send_request(10, buf, WaitMSCCookie, is_checked=is_checked)
     def WaitSBC(self, drawable, target_sbc_hi, target_sbc_lo, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIII", drawable, target_sbc_hi, target_sbc_lo))
         return self.send_request(11, buf, WaitSBCCookie, is_checked=is_checked)
     def SwapInterval(self, drawable, interval, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", drawable, interval))
         return self.send_request(12, buf, is_checked=is_checked)
     def GetParam(self, drawable, param, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", drawable, param))
         return self.send_request(13, buf, GetParamCookie, is_checked=is_checked)
 xcffib._add_ext(key, dri2Extension, _events, _errors)
